@@ -1,5 +1,5 @@
 package Test::Selenium::Firefox;
-$Test::Selenium::Firefox::VERSION = '1.49';
+$Test::Selenium::Firefox::VERSION = '1.50';
 use Moo;
 extends 'Selenium::Firefox', 'Test::Selenium::Remote::Driver';
 
@@ -14,7 +14,7 @@ __END__
 
 =head1 NAME
 
-Test::Selenium::Firefox
+Test::Selenium::Firefox - Test using Test::Selenium
 
 =head1 SYNOPSIS
 
